package de.juplo.thymeproxy;

import java.util.HashMap;
import java.util.Map;
import org.apache.http.impl.client.CloseableHttpClient;
import org.springframework.boot.SpringApplication;
import org.springframework.boot.autoconfigure.SpringBootApplication;
import org.springframework.context.annotation.Bean;
import org.springframework.core.Ordered;
import org.springframework.core.env.Environment;


@SpringBootApplication
public class Application
{
  @Bean
  public RegexUrlHandlerMapping proxiedHandlerMapping(
      ProxyHttpRequestHandler handler
      )
  {
    RegexUrlHandlerMapping mapping = new RegexUrlHandlerMapping();
    mapping.setOrder(Ordered.HIGHEST_PRECEDENCE);
    Map<String, Object> mappings = new HashMap<>();
    mappings.put(".*\\.html$", handler);
    mappings.put("/css/.+", handler);
    mappings.put("/js/.+", handler);
    mappings.put("/fonts/.+", handler);
    mappings.put("/.+/", handler);
    mapping.setUrlMap(mappings);
	return mapping;
  }

  @Bean
  public ProxyHttpRequestHandler proxiedRequestHandler(
      CloseableHttpClient client,
      Environment env
      )
  {
    ProxyHttpRequestHandler handler = new ProxyHttpRequestHandler();
    handler.setClient(client);
    handler.setOrigin(env.getProperty("thymeproxy.origin"));
    handler.setTtl(30000l);
    return handler;
  }


  public static void main(String[] args)
  {
    SpringApplication.run(Application.class, args);
  }
}